# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class Line(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Lines are lines in a single line graph
Each line has an optional label in case there is more than one line. This is also the value that will be presented in the chart legend
The dataseries is a list of points representing the line data
    """


    class MetaOapg:
        required = {
            "dataSeries",
            "label",
        }
        
        class properties:
            
            
            class dataSeries(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['Point']:
                        return Point
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['Point'], typing.List['Point']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'dataSeries':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'Point':
                    return super().__getitem__(i)
            label = schemas.StrSchema
            __annotations__ = {
                "dataSeries": dataSeries,
                "label": label,
            }
    
    dataSeries: MetaOapg.properties.dataSeries
    label: MetaOapg.properties.label
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["dataSeries"]) -> MetaOapg.properties.dataSeries: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["label"]) -> MetaOapg.properties.label: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["dataSeries", "label", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["dataSeries"]) -> MetaOapg.properties.dataSeries: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["label"]) -> MetaOapg.properties.label: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["dataSeries", "label", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        dataSeries: typing.Union[MetaOapg.properties.dataSeries, list, tuple, ],
        label: typing.Union[MetaOapg.properties.label, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Line':
        return super().__new__(
            cls,
            *args,
            dataSeries=dataSeries,
            label=label,
            _configuration=_configuration,
            **kwargs,
        )

from openapi_client.model.point import Point



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class EvaluateParams(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "versionId",
            "modelId",
            "trainingParams",
            "dataStates",
            "shouldRunPopulationExploration",
            "evaluatedEpoch",
        }
        
        class properties:
            versionId = schemas.StrSchema
            modelId = schemas.StrSchema
        
            @staticmethod
            def trainingParams() -> typing.Type['TrainingParams']:
                return TrainingParams
            
            
            class dataStates(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['DataStateForEval']:
                        return DataStateForEval
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['DataStateForEval'], typing.List['DataStateForEval']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'dataStates':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'DataStateForEval':
                    return super().__getitem__(i)
            shouldRunPopulationExploration = schemas.BoolSchema
            evaluatedEpoch = schemas.Float64Schema
            __annotations__ = {
                "versionId": versionId,
                "modelId": modelId,
                "trainingParams": trainingParams,
                "dataStates": dataStates,
                "shouldRunPopulationExploration": shouldRunPopulationExploration,
                "evaluatedEpoch": evaluatedEpoch,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    versionId: MetaOapg.properties.versionId
    modelId: MetaOapg.properties.modelId
    trainingParams: 'TrainingParams'
    dataStates: MetaOapg.properties.dataStates
    shouldRunPopulationExploration: MetaOapg.properties.shouldRunPopulationExploration
    evaluatedEpoch: MetaOapg.properties.evaluatedEpoch
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["versionId"]) -> MetaOapg.properties.versionId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["modelId"]) -> MetaOapg.properties.modelId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["trainingParams"]) -> 'TrainingParams': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["dataStates"]) -> MetaOapg.properties.dataStates: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["shouldRunPopulationExploration"]) -> MetaOapg.properties.shouldRunPopulationExploration: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["evaluatedEpoch"]) -> MetaOapg.properties.evaluatedEpoch: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["versionId"], typing_extensions.Literal["modelId"], typing_extensions.Literal["trainingParams"], typing_extensions.Literal["dataStates"], typing_extensions.Literal["shouldRunPopulationExploration"], typing_extensions.Literal["evaluatedEpoch"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["versionId"]) -> MetaOapg.properties.versionId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["modelId"]) -> MetaOapg.properties.modelId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["trainingParams"]) -> 'TrainingParams': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["dataStates"]) -> MetaOapg.properties.dataStates: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["shouldRunPopulationExploration"]) -> MetaOapg.properties.shouldRunPopulationExploration: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["evaluatedEpoch"]) -> MetaOapg.properties.evaluatedEpoch: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["versionId"], typing_extensions.Literal["modelId"], typing_extensions.Literal["trainingParams"], typing_extensions.Literal["dataStates"], typing_extensions.Literal["shouldRunPopulationExploration"], typing_extensions.Literal["evaluatedEpoch"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        versionId: typing.Union[MetaOapg.properties.versionId, str, ],
        modelId: typing.Union[MetaOapg.properties.modelId, str, ],
        trainingParams: 'TrainingParams',
        dataStates: typing.Union[MetaOapg.properties.dataStates, list, tuple, ],
        shouldRunPopulationExploration: typing.Union[MetaOapg.properties.shouldRunPopulationExploration, bool, ],
        evaluatedEpoch: typing.Union[MetaOapg.properties.evaluatedEpoch, decimal.Decimal, int, float, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'EvaluateParams':
        return super().__new__(
            cls,
            *args,
            versionId=versionId,
            modelId=modelId,
            trainingParams=trainingParams,
            dataStates=dataStates,
            shouldRunPopulationExploration=shouldRunPopulationExploration,
            evaluatedEpoch=evaluatedEpoch,
            _configuration=_configuration,
        )

from openapi_client.model.data_state_for_eval import DataStateForEval
from openapi_client.model.training_params import TrainingParams



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class StartTrialParams(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "firstName",
            "lastName",
            "email",
        }
        
        class properties:
            firstName = schemas.StrSchema
            lastName = schemas.StrSchema
            email = schemas.StrSchema
            phoneNumber = schemas.StrSchema
            role = schemas.StrSchema
            company = schemas.StrSchema
            __annotations__ = {
                "firstName": firstName,
                "lastName": lastName,
                "email": email,
                "phoneNumber": phoneNumber,
                "role": role,
                "company": company,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    firstName: MetaOapg.properties.firstName
    lastName: MetaOapg.properties.lastName
    email: MetaOapg.properties.email
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["firstName"]) -> MetaOapg.properties.firstName: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["lastName"]) -> MetaOapg.properties.lastName: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["email"]) -> MetaOapg.properties.email: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["phoneNumber"]) -> MetaOapg.properties.phoneNumber: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["role"]) -> MetaOapg.properties.role: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["company"]) -> MetaOapg.properties.company: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["firstName"], typing_extensions.Literal["lastName"], typing_extensions.Literal["email"], typing_extensions.Literal["phoneNumber"], typing_extensions.Literal["role"], typing_extensions.Literal["company"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["firstName"]) -> MetaOapg.properties.firstName: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["lastName"]) -> MetaOapg.properties.lastName: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["email"]) -> MetaOapg.properties.email: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["phoneNumber"]) -> typing.Union[MetaOapg.properties.phoneNumber, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["role"]) -> typing.Union[MetaOapg.properties.role, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["company"]) -> typing.Union[MetaOapg.properties.company, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["firstName"], typing_extensions.Literal["lastName"], typing_extensions.Literal["email"], typing_extensions.Literal["phoneNumber"], typing_extensions.Literal["role"], typing_extensions.Literal["company"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        firstName: typing.Union[MetaOapg.properties.firstName, str, ],
        lastName: typing.Union[MetaOapg.properties.lastName, str, ],
        email: typing.Union[MetaOapg.properties.email, str, ],
        phoneNumber: typing.Union[MetaOapg.properties.phoneNumber, str, schemas.Unset] = schemas.unset,
        role: typing.Union[MetaOapg.properties.role, str, schemas.Unset] = schemas.unset,
        company: typing.Union[MetaOapg.properties.company, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'StartTrialParams':
        return super().__new__(
            cls,
            *args,
            firstName=firstName,
            lastName=lastName,
            email=email,
            phoneNumber=phoneNumber,
            role=role,
            company=company,
            _configuration=_configuration,
        )



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class XYChartsMeta(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    XYChartMeta contains defining information on all the charts in this dashlet including what their type is, what the elements range is, the axis types, display names, labels and more
    """


    class MetaOapg:
        required = {
            "yAxis",
            "xAxis",
        }
        
        class properties:
        
            @staticmethod
            def xAxis() -> typing.Type['XMetaAxis']:
                return XMetaAxis
        
            @staticmethod
            def yAxis() -> typing.Type['YMetaAxis']:
                return YMetaAxis
            __annotations__ = {
                "xAxis": xAxis,
                "yAxis": yAxis,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    yAxis: 'YMetaAxis'
    xAxis: 'XMetaAxis'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["yAxis"]) -> 'YMetaAxis': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["xAxis"]) -> 'XMetaAxis': ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["yAxis"], typing_extensions.Literal["xAxis"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["yAxis"]) -> 'YMetaAxis': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["xAxis"]) -> 'XMetaAxis': ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["yAxis"], typing_extensions.Literal["xAxis"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        yAxis: 'YMetaAxis',
        xAxis: 'XMetaAxis',
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'XYChartsMeta':
        return super().__new__(
            cls,
            *args,
            yAxis=yAxis,
            xAxis=xAxis,
            _configuration=_configuration,
        )

from openapi_client.model.x_meta_axis import XMetaAxis
from openapi_client.model.y_meta_axis import YMetaAxis



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class DatasetTestResultPayload(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "is_passed",
            "display",
            "name",
        }
        
        class properties:
            name = schemas.StrSchema
            display = schemas.DictSchema
            is_passed = schemas.BoolSchema
            
            
            class shape(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.Float64Schema
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, decimal.Decimal, int, float, ]], typing.List[typing.Union[MetaOapg.items, decimal.Decimal, int, float, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'shape':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            __annotations__ = {
                "name": name,
                "display": display,
                "is_passed": is_passed,
                "shape": shape,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    is_passed: MetaOapg.properties.is_passed
    display: MetaOapg.properties.display
    name: MetaOapg.properties.name
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["is_passed"]) -> MetaOapg.properties.is_passed: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["display"]) -> MetaOapg.properties.display: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["shape"]) -> MetaOapg.properties.shape: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["is_passed"], typing_extensions.Literal["display"], typing_extensions.Literal["name"], typing_extensions.Literal["shape"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["is_passed"]) -> MetaOapg.properties.is_passed: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["display"]) -> MetaOapg.properties.display: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["shape"]) -> typing.Union[MetaOapg.properties.shape, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["is_passed"], typing_extensions.Literal["display"], typing_extensions.Literal["name"], typing_extensions.Literal["shape"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        is_passed: typing.Union[MetaOapg.properties.is_passed, bool, ],
        display: typing.Union[MetaOapg.properties.display, dict, frozendict.frozendict, ],
        name: typing.Union[MetaOapg.properties.name, str, ],
        shape: typing.Union[MetaOapg.properties.shape, list, tuple, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'DatasetTestResultPayload':
        return super().__new__(
            cls,
            *args,
            is_passed=is_passed,
            display=display,
            name=name,
            shape=shape,
            _configuration=_configuration,
        )



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class IssueAction(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        class properties:
        
            @staticmethod
            def assignment() -> typing.Type['ActionAssignmentElement']:
                return ActionAssignmentElement
        
            @staticmethod
            def tagsAdded() -> typing.Type['ActionTagElement']:
                return ActionTagElement
        
            @staticmethod
            def comment() -> typing.Type['ActionCommentElement']:
                return ActionCommentElement
            __annotations__ = {
                "assignment": assignment,
                "tagsAdded": tagsAdded,
                "comment": comment,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["assignment"]) -> 'ActionAssignmentElement': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["tagsAdded"]) -> 'ActionTagElement': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["comment"]) -> 'ActionCommentElement': ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["assignment"], typing_extensions.Literal["tagsAdded"], typing_extensions.Literal["comment"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["assignment"]) -> typing.Union['ActionAssignmentElement', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["tagsAdded"]) -> typing.Union['ActionTagElement', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["comment"]) -> typing.Union['ActionCommentElement', schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["assignment"], typing_extensions.Literal["tagsAdded"], typing_extensions.Literal["comment"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        assignment: typing.Union['ActionAssignmentElement', schemas.Unset] = schemas.unset,
        tagsAdded: typing.Union['ActionTagElement', schemas.Unset] = schemas.unset,
        comment: typing.Union['ActionCommentElement', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'IssueAction':
        return super().__new__(
            cls,
            *args,
            assignment=assignment,
            tagsAdded=tagsAdded,
            comment=comment,
            _configuration=_configuration,
        )

from openapi_client.model.action_assignment_element import ActionAssignmentElement
from openapi_client.model.action_comment_element import ActionCommentElement
from openapi_client.model.action_tag_element import ActionTagElement



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class SaveDatasetVersionParams(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "saveAsNew",
            "isValid",
            "datasetId",
            "script",
        }
        
        class properties:
            datasetId = schemas.StrSchema
            saveAsNew = schemas.BoolSchema
            isValid = schemas.BoolSchema
            script = schemas.StrSchema
        
            @staticmethod
            def setup() -> typing.Type['DatasetSetup']:
                return DatasetSetup
            saveAsNewName = schemas.StrSchema
            secretManagerId = schemas.StrSchema
            testToken = schemas.StrSchema
            note = schemas.StrSchema
            __annotations__ = {
                "datasetId": datasetId,
                "saveAsNew": saveAsNew,
                "isValid": isValid,
                "script": script,
                "setup": setup,
                "saveAsNewName": saveAsNewName,
                "secretManagerId": secretManagerId,
                "testToken": testToken,
                "note": note,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    saveAsNew: MetaOapg.properties.saveAsNew
    isValid: MetaOapg.properties.isValid
    datasetId: MetaOapg.properties.datasetId
    script: MetaOapg.properties.script
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["saveAsNew"]) -> MetaOapg.properties.saveAsNew: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["isValid"]) -> MetaOapg.properties.isValid: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["datasetId"]) -> MetaOapg.properties.datasetId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["script"]) -> MetaOapg.properties.script: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["setup"]) -> 'DatasetSetup': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["saveAsNewName"]) -> MetaOapg.properties.saveAsNewName: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["secretManagerId"]) -> MetaOapg.properties.secretManagerId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["testToken"]) -> MetaOapg.properties.testToken: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["note"]) -> MetaOapg.properties.note: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["saveAsNew"], typing_extensions.Literal["isValid"], typing_extensions.Literal["datasetId"], typing_extensions.Literal["script"], typing_extensions.Literal["setup"], typing_extensions.Literal["saveAsNewName"], typing_extensions.Literal["secretManagerId"], typing_extensions.Literal["testToken"], typing_extensions.Literal["note"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["saveAsNew"]) -> MetaOapg.properties.saveAsNew: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["isValid"]) -> MetaOapg.properties.isValid: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["datasetId"]) -> MetaOapg.properties.datasetId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["script"]) -> MetaOapg.properties.script: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["setup"]) -> typing.Union['DatasetSetup', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["saveAsNewName"]) -> typing.Union[MetaOapg.properties.saveAsNewName, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["secretManagerId"]) -> typing.Union[MetaOapg.properties.secretManagerId, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["testToken"]) -> typing.Union[MetaOapg.properties.testToken, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["note"]) -> typing.Union[MetaOapg.properties.note, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["saveAsNew"], typing_extensions.Literal["isValid"], typing_extensions.Literal["datasetId"], typing_extensions.Literal["script"], typing_extensions.Literal["setup"], typing_extensions.Literal["saveAsNewName"], typing_extensions.Literal["secretManagerId"], typing_extensions.Literal["testToken"], typing_extensions.Literal["note"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        saveAsNew: typing.Union[MetaOapg.properties.saveAsNew, bool, ],
        isValid: typing.Union[MetaOapg.properties.isValid, bool, ],
        datasetId: typing.Union[MetaOapg.properties.datasetId, str, ],
        script: typing.Union[MetaOapg.properties.script, str, ],
        setup: typing.Union['DatasetSetup', schemas.Unset] = schemas.unset,
        saveAsNewName: typing.Union[MetaOapg.properties.saveAsNewName, str, schemas.Unset] = schemas.unset,
        secretManagerId: typing.Union[MetaOapg.properties.secretManagerId, str, schemas.Unset] = schemas.unset,
        testToken: typing.Union[MetaOapg.properties.testToken, str, schemas.Unset] = schemas.unset,
        note: typing.Union[MetaOapg.properties.note, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'SaveDatasetVersionParams':
        return super().__new__(
            cls,
            *args,
            saveAsNew=saveAsNew,
            isValid=isValid,
            datasetId=datasetId,
            script=script,
            setup=setup,
            saveAsNewName=saveAsNewName,
            secretManagerId=secretManagerId,
            testToken=testToken,
            note=note,
            _configuration=_configuration,
        )

from openapi_client.model.dataset_setup import DatasetSetup



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class ImageData(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "blob",
            "src",
            "type",
        }
        
        class properties:
            src = schemas.StrSchema
            blob = schemas.StrSchema
        
            @staticmethod
            def type() -> typing.Type['DataTypeEnum']:
                return DataTypeEnum
            __annotations__ = {
                "src": src,
                "blob": blob,
                "type": type,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    blob: MetaOapg.properties.blob
    src: MetaOapg.properties.src
    type: 'DataTypeEnum'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["blob"]) -> MetaOapg.properties.blob: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["src"]) -> MetaOapg.properties.src: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> 'DataTypeEnum': ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["blob"], typing_extensions.Literal["src"], typing_extensions.Literal["type"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["blob"]) -> MetaOapg.properties.blob: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["src"]) -> MetaOapg.properties.src: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> 'DataTypeEnum': ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["blob"], typing_extensions.Literal["src"], typing_extensions.Literal["type"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        blob: typing.Union[MetaOapg.properties.blob, str, ],
        src: typing.Union[MetaOapg.properties.src, str, ],
        type: 'DataTypeEnum',
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'ImageData':
        return super().__new__(
            cls,
            *args,
            blob=blob,
            src=src,
            type=type,
            _configuration=_configuration,
        )

from openapi_client.model.data_type_enum import DataTypeEnum



import typing_extensions

from openapi_client.paths import PathValues
from openapi_client.apis.paths.auth_keylogin import AuthKeylogin
from openapi_client.apis.paths.auth_login import AuthLogin
from openapi_client.apis.paths.auth_keygen import AuthKeygen
from openapi_client.apis.paths.auth_who_am_i import AuthWhoAmI
from openapi_client.apis.paths.auth_signup import AuthSignup
from openapi_client.apis.paths.auth_activate import AuthActivate
from openapi_client.apis.paths.auth_resend_activation_mail import AuthResendActivationMail
from openapi_client.apis.paths.auth_send_reset_password_mail import AuthSendResetPasswordMail
from openapi_client.apis.paths.auth_reset_password import AuthResetPassword
from openapi_client.apis.paths.auth_set_user_metadata import AuthSetUserMetadata
from openapi_client.apis.paths.auth_request_trial import AuthRequestTrial
from openapi_client.apis.paths.auth_start_trial import AuthStartTrial
from openapi_client.apis.paths.auth_extend_trial import AuthExtendTrial
from openapi_client.apis.paths.auth_logout import AuthLogout
from openapi_client.apis.paths.dashboards_get_kibana_dashboards import DashboardsGetKibanaDashboards
from openapi_client.apis.paths.dashboards_get_project_dashboards import DashboardsGetProjectDashboards
from openapi_client.apis.paths.dashboards_get_dashboard import DashboardsGetDashboard
from openapi_client.apis.paths.dashboards_add_dashboard import DashboardsAddDashboard
from openapi_client.apis.paths.dashboards_delete_dashboard import DashboardsDeleteDashboard
from openapi_client.apis.paths.dashboards_update_dashboard import DashboardsUpdateDashboard
from openapi_client.apis.paths.dashboards_get_kibana_dashlet_fields import DashboardsGetKibanaDashletFields
from openapi_client.apis.paths.dashboards_get_dashlet_fields import DashboardsGetDashletFields
from openapi_client.apis.paths.datasets_get_datasets import DatasetsGetDatasets
from openapi_client.apis.paths.datasets_add_dataset import DatasetsAddDataset
from openapi_client.apis.paths.datasets_trash_dataset import DatasetsTrashDataset
from openapi_client.apis.paths.datasets_save_dataset_version import DatasetsSaveDatasetVersion
from openapi_client.apis.paths.datasets_modify_dataset_version_note import DatasetsModifyDatasetVersionNote
from openapi_client.apis.paths.datasets_parse_dataset import DatasetsParseDataset
from openapi_client.apis.paths.datasets_get_dataset_version import DatasetsGetDatasetVersion
from openapi_client.apis.paths.datasets_get_latest_dataset_version import DatasetsGetLatestDatasetVersion
from openapi_client.apis.paths.datasets_get_dataset_versions import DatasetsGetDatasetVersions
from openapi_client.apis.paths.demos_get_demos import DemosGetDemos
from openapi_client.apis.paths.demos_import_demo_project import DemosImportDemoProject
from openapi_client.apis.paths.demos_send_user_message import DemosSendUserMessage
from openapi_client.apis.paths.exportedmodels_get_exported_model_jobs import ExportedmodelsGetExportedModelJobs
from openapi_client.apis.paths.exportedmodels_get_stored_exported_model_resource_url import ExportedmodelsGetStoredExportedModelResourceUrl
from openapi_client.apis.paths.insights_get_model_insights import InsightsGetModelInsights
from openapi_client.apis.paths.issues_get_project_issues import IssuesGetProjectIssues
from openapi_client.apis.paths.issues_get_single_issue import IssuesGetSingleIssue
from openapi_client.apis.paths.issues_update_issue import IssuesUpdateIssue
from openapi_client.apis.paths.issues_add_issue import IssuesAddIssue
from openapi_client.apis.paths.issues_delete_issue import IssuesDeleteIssue
from openapi_client.apis.paths.jobs_get_jobs import JobsGetJobs
from openapi_client.apis.paths.jobs_get_training_jobs import JobsGetTrainingJobs
from openapi_client.apis.paths.jobs_is_training_job_running import JobsIsTrainingJobRunning
from openapi_client.apis.paths.jobs_get_organization_jobs import JobsGetOrganizationJobs
from openapi_client.apis.paths.jobs_stop_job import JobsStopJob
from openapi_client.apis.paths.jobs_terminate_job import JobsTerminateJob
from openapi_client.apis.paths.jobs_warmup import JobsWarmup
from openapi_client.apis.paths.jobs_add_export_model_job import JobsAddExportModelJob
from openapi_client.apis.paths.jobs_train_from_scratch import JobsTrainFromScratch
from openapi_client.apis.paths.jobs_continue_train import JobsContinueTrain
from openapi_client.apis.paths.jobs_train_from_initial_weights import JobsTrainFromInitialWeights
from openapi_client.apis.paths.jobs_evaluate import JobsEvaluate
from openapi_client.apis.paths.jobs_sample_analysis import JobsSampleAnalysis
from openapi_client.apis.paths.jobs_population_exploration import JobsPopulationExploration
from openapi_client.apis.paths.jobs_sample_selection import JobsSampleSelection
from openapi_client.apis.paths.jobs_get_machine_types import JobsGetMachineTypes
from openapi_client.apis.paths.jobs_set_machine_type import JobsSetMachineType
from openapi_client.apis.paths.metadata_get_max_active_users import MetadataGetMaxActiveUsers
from openapi_client.apis.paths.metadata_get_statistics import MetadataGetStatistics
from openapi_client.apis.paths.model_tests_create_model_test import ModelTestsCreateModelTest
from openapi_client.apis.paths.model_tests_update_model_test import ModelTestsUpdateModelTest
from openapi_client.apis.paths.model_tests_get_single_model_test import ModelTestsGetSingleModelTest
from openapi_client.apis.paths.model_tests_get_all_project_model_tests import ModelTestsGetAllProjectModelTests
from openapi_client.apis.paths.model_tests_delete_model_test import ModelTestsDeleteModelTest
from openapi_client.apis.paths.model_tests_get_model_test_result import ModelTestsGetModelTestResult
from openapi_client.apis.paths.modelmetrics_get_model_epoch_loss import ModelmetricsGetModelEpochLoss
from openapi_client.apis.paths.modelmetrics_get_xy_chart import ModelmetricsGetXYChart
from openapi_client.apis.paths.modelmetrics_get_heatmap_chart import ModelmetricsGetHeatmapChart
from openapi_client.apis.paths.modelmetrics_get_table_chart import ModelmetricsGetTableChart
from openapi_client.apis.paths.modelmetrics_get_confusion_metric_names import ModelmetricsGetConfusionMetricNames
from openapi_client.apis.paths.modelmetrics_get_balanced_accuracy import ModelmetricsGetBalancedAccuracy
from openapi_client.apis.paths.modelmetrics_get_f1_score import ModelmetricsGetF1Score
from openapi_client.apis.paths.modelmetrics_get_pr_curve import ModelmetricsGetPrCurve
from openapi_client.apis.paths.modelmetrics_get_roc import ModelmetricsGetRoc
from openapi_client.apis.paths.models_get_models_by_hash import ModelsGetModelsByHash
from openapi_client.apis.paths.models_get_models_by_version_id import ModelsGetModelsByVersionId
from openapi_client.apis.paths.models_get_recent_organization_models import ModelsGetRecentOrganizationModels
from openapi_client.apis.paths.models_delete_model import ModelsDeleteModel
from openapi_client.apis.paths.monitor_health_check import MonitorHealthCheck
from openapi_client.apis.paths.notifications_get_notifications import NotificationsGetNotifications
from openapi_client.apis.paths.notifications_set_user_notifications_as_read import NotificationsSetUserNotificationsAsRead
from openapi_client.apis.paths.organizations_get_organizations import OrganizationsGetOrganizations
from openapi_client.apis.paths.organizations_update_organization_public_name import OrganizationsUpdateOrganizationPublicName
from openapi_client.apis.paths.organizations_create_organization import OrganizationsCreateOrganization
from openapi_client.apis.paths.organizations_delete_organization import OrganizationsDeleteOrganization
from openapi_client.apis.paths.organizations_set_default_organization import OrganizationsSetDefaultOrganization
from openapi_client.apis.paths.projects_add_project import ProjectsAddProject
from openapi_client.apis.paths.projects_get_projects import ProjectsGetProjects
from openapi_client.apis.paths.projects_load_model import ProjectsLoadModel
from openapi_client.apis.paths.projects_delete_project import ProjectsDeleteProject
from openapi_client.apis.paths.projects_trash_project import ProjectsTrashProject
from openapi_client.apis.paths.projects_get_current_project_version import ProjectsGetCurrentProjectVersion
from openapi_client.apis.paths.secret_manager_add_secret_manager import SecretManagerAddSecretManager
from openapi_client.apis.paths.secret_manager_trash_secret_manager import SecretManagerTrashSecretManager
from openapi_client.apis.paths.secret_manager_get_secret_manager_list import SecretManagerGetSecretManagerList
from openapi_client.apis.paths.secret_manager_update_secret_manager import SecretManagerUpdateSecretManager
from openapi_client.apis.paths.users_get_organization_slim_user_data import UsersGetOrganizationSlimUserData
from openapi_client.apis.paths.users_get_all_slim_user_data import UsersGetAllSlimUserData
from openapi_client.apis.paths.users_update_user_status import UsersUpdateUserStatus
from openapi_client.apis.paths.users_update_user_organization import UsersUpdateUserOrganization
from openapi_client.apis.paths.users_update_user_role import UsersUpdateUserRole
from openapi_client.apis.paths.users_update_user_name import UsersUpdateUserName
from openapi_client.apis.paths.users_delete_user_by_id import UsersDeleteUserById
from openapi_client.apis.paths.versions_import_model import VersionsImportModel
from openapi_client.apis.paths.versions_add_version import VersionsAddVersion
from openapi_client.apis.paths.versions_load_version import VersionsLoadVersion
from openapi_client.apis.paths.versions_delete_version import VersionsDeleteVersion
from openapi_client.apis.paths.versions_update_version import VersionsUpdateVersion
from openapi_client.apis.paths.versions_get_project_slim_versions import VersionsGetProjectSlimVersions
from openapi_client.apis.paths.versions_get_upload_signed_url import VersionsGetUploadSignedUrl
from openapi_client.apis.paths.visualizations_get_visualization import VisualizationsGetVisualization
from openapi_client.apis.paths.visualizations_get_model_visualizations import VisualizationsGetModelVisualizations
from openapi_client.apis.paths.visualizations_save_analyzer_layout import VisualizationsSaveAnalyzerLayout
from openapi_client.apis.paths.visualizations_delete_visualizations import VisualizationsDeleteVisualizations
from openapi_client.apis.paths.visualizations_get_stored_resource_url import VisualizationsGetStoredResourceUrl

PathToApi = typing_extensions.TypedDict(
    'PathToApi',
    {
        PathValues.AUTH_KEYLOGIN: AuthKeylogin,
        PathValues.AUTH_LOGIN: AuthLogin,
        PathValues.AUTH_KEYGEN: AuthKeygen,
        PathValues.AUTH_WHO_AM_I: AuthWhoAmI,
        PathValues.AUTH_SIGNUP: AuthSignup,
        PathValues.AUTH_ACTIVATE: AuthActivate,
        PathValues.AUTH_RESEND_ACTIVATION_MAIL: AuthResendActivationMail,
        PathValues.AUTH_SEND_RESET_PASSWORD_MAIL: AuthSendResetPasswordMail,
        PathValues.AUTH_RESET_PASSWORD: AuthResetPassword,
        PathValues.AUTH_SET_USER_METADATA: AuthSetUserMetadata,
        PathValues.AUTH_REQUEST_TRIAL: AuthRequestTrial,
        PathValues.AUTH_START_TRIAL: AuthStartTrial,
        PathValues.AUTH_EXTEND_TRIAL: AuthExtendTrial,
        PathValues.AUTH_LOGOUT: AuthLogout,
        PathValues.DASHBOARDS_GET_KIBANA_DASHBOARDS: DashboardsGetKibanaDashboards,
        PathValues.DASHBOARDS_GET_PROJECT_DASHBOARDS: DashboardsGetProjectDashboards,
        PathValues.DASHBOARDS_GET_DASHBOARD: DashboardsGetDashboard,
        PathValues.DASHBOARDS_ADD_DASHBOARD: DashboardsAddDashboard,
        PathValues.DASHBOARDS_DELETE_DASHBOARD: DashboardsDeleteDashboard,
        PathValues.DASHBOARDS_UPDATE_DASHBOARD: DashboardsUpdateDashboard,
        PathValues.DASHBOARDS_GET_KIBANA_DASHLET_FIELDS: DashboardsGetKibanaDashletFields,
        PathValues.DASHBOARDS_GET_DASHLET_FIELDS: DashboardsGetDashletFields,
        PathValues.DATASETS_GET_DATASETS: DatasetsGetDatasets,
        PathValues.DATASETS_ADD_DATASET: DatasetsAddDataset,
        PathValues.DATASETS_TRASH_DATASET: DatasetsTrashDataset,
        PathValues.DATASETS_SAVE_DATASET_VERSION: DatasetsSaveDatasetVersion,
        PathValues.DATASETS_MODIFY_DATASET_VERSION_NOTE: DatasetsModifyDatasetVersionNote,
        PathValues.DATASETS_PARSE_DATASET: DatasetsParseDataset,
        PathValues.DATASETS_GET_DATASET_VERSION: DatasetsGetDatasetVersion,
        PathValues.DATASETS_GET_LATEST_DATASET_VERSION: DatasetsGetLatestDatasetVersion,
        PathValues.DATASETS_GET_DATASET_VERSIONS: DatasetsGetDatasetVersions,
        PathValues.DEMOS_GET_DEMOS: DemosGetDemos,
        PathValues.DEMOS_IMPORT_DEMO_PROJECT: DemosImportDemoProject,
        PathValues.DEMOS_SEND_USER_MESSAGE: DemosSendUserMessage,
        PathValues.EXPORTEDMODELS_GET_EXPORTED_MODEL_JOBS: ExportedmodelsGetExportedModelJobs,
        PathValues.EXPORTEDMODELS_GET_STORED_EXPORTED_MODEL_RESOURCE_URL: ExportedmodelsGetStoredExportedModelResourceUrl,
        PathValues.INSIGHTS_GET_MODEL_INSIGHTS: InsightsGetModelInsights,
        PathValues.ISSUES_GET_PROJECT_ISSUES: IssuesGetProjectIssues,
        PathValues.ISSUES_GET_SINGLE_ISSUE: IssuesGetSingleIssue,
        PathValues.ISSUES_UPDATE_ISSUE: IssuesUpdateIssue,
        PathValues.ISSUES_ADD_ISSUE: IssuesAddIssue,
        PathValues.ISSUES_DELETE_ISSUE: IssuesDeleteIssue,
        PathValues.JOBS_GET_JOBS: JobsGetJobs,
        PathValues.JOBS_GET_TRAINING_JOBS: JobsGetTrainingJobs,
        PathValues.JOBS_IS_TRAINING_JOB_RUNNING: JobsIsTrainingJobRunning,
        PathValues.JOBS_GET_ORGANIZATION_JOBS: JobsGetOrganizationJobs,
        PathValues.JOBS_STOP_JOB: JobsStopJob,
        PathValues.JOBS_TERMINATE_JOB: JobsTerminateJob,
        PathValues.JOBS_WARMUP: JobsWarmup,
        PathValues.JOBS_ADD_EXPORT_MODEL_JOB: JobsAddExportModelJob,
        PathValues.JOBS_TRAIN_FROM_SCRATCH: JobsTrainFromScratch,
        PathValues.JOBS_CONTINUE_TRAIN: JobsContinueTrain,
        PathValues.JOBS_TRAIN_FROM_INITIAL_WEIGHTS: JobsTrainFromInitialWeights,
        PathValues.JOBS_EVALUATE: JobsEvaluate,
        PathValues.JOBS_SAMPLE_ANALYSIS: JobsSampleAnalysis,
        PathValues.JOBS_POPULATION_EXPLORATION: JobsPopulationExploration,
        PathValues.JOBS_SAMPLE_SELECTION: JobsSampleSelection,
        PathValues.JOBS_GET_MACHINE_TYPES: JobsGetMachineTypes,
        PathValues.JOBS_SET_MACHINE_TYPE: JobsSetMachineType,
        PathValues.METADATA_GET_MAX_ACTIVE_USERS: MetadataGetMaxActiveUsers,
        PathValues.METADATA_GET_STATISTICS: MetadataGetStatistics,
        PathValues.MODELTESTS_CREATE_MODEL_TEST: ModelTestsCreateModelTest,
        PathValues.MODELTESTS_UPDATE_MODEL_TEST: ModelTestsUpdateModelTest,
        PathValues.MODELTESTS_GET_SINGLE_MODEL_TEST: ModelTestsGetSingleModelTest,
        PathValues.MODELTESTS_GET_ALL_PROJECT_MODEL_TESTS: ModelTestsGetAllProjectModelTests,
        PathValues.MODELTESTS_DELETE_MODEL_TEST: ModelTestsDeleteModelTest,
        PathValues.MODELTESTS_GET_MODEL_TEST_RESULT: ModelTestsGetModelTestResult,
        PathValues.MODELMETRICS_GET_MODEL_EPOCH_LOSS: ModelmetricsGetModelEpochLoss,
        PathValues.MODELMETRICS_GET_XYCHART: ModelmetricsGetXYChart,
        PathValues.MODELMETRICS_GET_HEATMAP_CHART: ModelmetricsGetHeatmapChart,
        PathValues.MODELMETRICS_GET_TABLE_CHART: ModelmetricsGetTableChart,
        PathValues.MODELMETRICS_GET_CONFUSION_METRIC_NAMES: ModelmetricsGetConfusionMetricNames,
        PathValues.MODELMETRICS_GET_BALANCED_ACCURACY: ModelmetricsGetBalancedAccuracy,
        PathValues.MODELMETRICS_GET_F1SCORE: ModelmetricsGetF1Score,
        PathValues.MODELMETRICS_GET_PR_CURVE: ModelmetricsGetPrCurve,
        PathValues.MODELMETRICS_GET_ROC: ModelmetricsGetRoc,
        PathValues.MODELS_GET_MODELS_BY_HASH: ModelsGetModelsByHash,
        PathValues.MODELS_GET_MODELS_BY_VERSION_ID: ModelsGetModelsByVersionId,
        PathValues.MODELS_GET_RECENT_ORGANIZATION_MODELS: ModelsGetRecentOrganizationModels,
        PathValues.MODELS_DELETE_MODEL: ModelsDeleteModel,
        PathValues.MONITOR_HEALTH_CHECK: MonitorHealthCheck,
        PathValues.NOTIFICATIONS_GET_NOTIFICATIONS: NotificationsGetNotifications,
        PathValues.NOTIFICATIONS_SET_USER_NOTIFICATIONS_AS_READ: NotificationsSetUserNotificationsAsRead,
        PathValues.ORGANIZATIONS_GET_ORGANIZATIONS: OrganizationsGetOrganizations,
        PathValues.ORGANIZATIONS_UPDATE_ORGANIZATION_PUBLIC_NAME: OrganizationsUpdateOrganizationPublicName,
        PathValues.ORGANIZATIONS_CREATE_ORGANIZATION: OrganizationsCreateOrganization,
        PathValues.ORGANIZATIONS_DELETE_ORGANIZATION: OrganizationsDeleteOrganization,
        PathValues.ORGANIZATIONS_SET_DEFAULT_ORGANIZATION: OrganizationsSetDefaultOrganization,
        PathValues.PROJECTS_ADD_PROJECT: ProjectsAddProject,
        PathValues.PROJECTS_GET_PROJECTS: ProjectsGetProjects,
        PathValues.PROJECTS_LOAD_MODEL: ProjectsLoadModel,
        PathValues.PROJECTS_DELETE_PROJECT: ProjectsDeleteProject,
        PathValues.PROJECTS_TRASH_PROJECT: ProjectsTrashProject,
        PathValues.PROJECTS_GET_CURRENT_PROJECT_VERSION: ProjectsGetCurrentProjectVersion,
        PathValues.SECRETMANAGER_ADD_SECRET_MANAGER: SecretManagerAddSecretManager,
        PathValues.SECRETMANAGER_TRASH_SECRET_MANAGER: SecretManagerTrashSecretManager,
        PathValues.SECRETMANAGER_GET_SECRET_MANAGER_LIST: SecretManagerGetSecretManagerList,
        PathValues.SECRETMANAGER_UPDATE_SECRET_MANAGER: SecretManagerUpdateSecretManager,
        PathValues.USERS_GET_ORGANIZATION_SLIM_USER_DATA: UsersGetOrganizationSlimUserData,
        PathValues.USERS_GET_ALL_SLIM_USER_DATA: UsersGetAllSlimUserData,
        PathValues.USERS_UPDATE_USER_STATUS: UsersUpdateUserStatus,
        PathValues.USERS_UPDATE_USER_ORGANIZATION: UsersUpdateUserOrganization,
        PathValues.USERS_UPDATE_USER_ROLE: UsersUpdateUserRole,
        PathValues.USERS_UPDATE_USER_NAME: UsersUpdateUserName,
        PathValues.USERS_DELETE_USER_BY_ID: UsersDeleteUserById,
        PathValues.VERSIONS_IMPORT_MODEL: VersionsImportModel,
        PathValues.VERSIONS_ADD_VERSION: VersionsAddVersion,
        PathValues.VERSIONS_LOAD_VERSION: VersionsLoadVersion,
        PathValues.VERSIONS_DELETE_VERSION: VersionsDeleteVersion,
        PathValues.VERSIONS_UPDATE_VERSION: VersionsUpdateVersion,
        PathValues.VERSIONS_GET_PROJECT_SLIM_VERSIONS: VersionsGetProjectSlimVersions,
        PathValues.VERSIONS_GET_UPLOAD_SIGNED_URL: VersionsGetUploadSignedUrl,
        PathValues.VISUALIZATIONS_GET_VISUALIZATION: VisualizationsGetVisualization,
        PathValues.VISUALIZATIONS_GET_MODEL_VISUALIZATIONS: VisualizationsGetModelVisualizations,
        PathValues.VISUALIZATIONS_SAVE_ANALYZER_LAYOUT: VisualizationsSaveAnalyzerLayout,
        PathValues.VISUALIZATIONS_DELETE_VISUALIZATIONS: VisualizationsDeleteVisualizations,
        PathValues.VISUALIZATIONS_GET_STORED_RESOURCE_URL: VisualizationsGetStoredResourceUrl,
    }
)

path_to_api = PathToApi(
    {
        PathValues.AUTH_KEYLOGIN: AuthKeylogin,
        PathValues.AUTH_LOGIN: AuthLogin,
        PathValues.AUTH_KEYGEN: AuthKeygen,
        PathValues.AUTH_WHO_AM_I: AuthWhoAmI,
        PathValues.AUTH_SIGNUP: AuthSignup,
        PathValues.AUTH_ACTIVATE: AuthActivate,
        PathValues.AUTH_RESEND_ACTIVATION_MAIL: AuthResendActivationMail,
        PathValues.AUTH_SEND_RESET_PASSWORD_MAIL: AuthSendResetPasswordMail,
        PathValues.AUTH_RESET_PASSWORD: AuthResetPassword,
        PathValues.AUTH_SET_USER_METADATA: AuthSetUserMetadata,
        PathValues.AUTH_REQUEST_TRIAL: AuthRequestTrial,
        PathValues.AUTH_START_TRIAL: AuthStartTrial,
        PathValues.AUTH_EXTEND_TRIAL: AuthExtendTrial,
        PathValues.AUTH_LOGOUT: AuthLogout,
        PathValues.DASHBOARDS_GET_KIBANA_DASHBOARDS: DashboardsGetKibanaDashboards,
        PathValues.DASHBOARDS_GET_PROJECT_DASHBOARDS: DashboardsGetProjectDashboards,
        PathValues.DASHBOARDS_GET_DASHBOARD: DashboardsGetDashboard,
        PathValues.DASHBOARDS_ADD_DASHBOARD: DashboardsAddDashboard,
        PathValues.DASHBOARDS_DELETE_DASHBOARD: DashboardsDeleteDashboard,
        PathValues.DASHBOARDS_UPDATE_DASHBOARD: DashboardsUpdateDashboard,
        PathValues.DASHBOARDS_GET_KIBANA_DASHLET_FIELDS: DashboardsGetKibanaDashletFields,
        PathValues.DASHBOARDS_GET_DASHLET_FIELDS: DashboardsGetDashletFields,
        PathValues.DATASETS_GET_DATASETS: DatasetsGetDatasets,
        PathValues.DATASETS_ADD_DATASET: DatasetsAddDataset,
        PathValues.DATASETS_TRASH_DATASET: DatasetsTrashDataset,
        PathValues.DATASETS_SAVE_DATASET_VERSION: DatasetsSaveDatasetVersion,
        PathValues.DATASETS_MODIFY_DATASET_VERSION_NOTE: DatasetsModifyDatasetVersionNote,
        PathValues.DATASETS_PARSE_DATASET: DatasetsParseDataset,
        PathValues.DATASETS_GET_DATASET_VERSION: DatasetsGetDatasetVersion,
        PathValues.DATASETS_GET_LATEST_DATASET_VERSION: DatasetsGetLatestDatasetVersion,
        PathValues.DATASETS_GET_DATASET_VERSIONS: DatasetsGetDatasetVersions,
        PathValues.DEMOS_GET_DEMOS: DemosGetDemos,
        PathValues.DEMOS_IMPORT_DEMO_PROJECT: DemosImportDemoProject,
        PathValues.DEMOS_SEND_USER_MESSAGE: DemosSendUserMessage,
        PathValues.EXPORTEDMODELS_GET_EXPORTED_MODEL_JOBS: ExportedmodelsGetExportedModelJobs,
        PathValues.EXPORTEDMODELS_GET_STORED_EXPORTED_MODEL_RESOURCE_URL: ExportedmodelsGetStoredExportedModelResourceUrl,
        PathValues.INSIGHTS_GET_MODEL_INSIGHTS: InsightsGetModelInsights,
        PathValues.ISSUES_GET_PROJECT_ISSUES: IssuesGetProjectIssues,
        PathValues.ISSUES_GET_SINGLE_ISSUE: IssuesGetSingleIssue,
        PathValues.ISSUES_UPDATE_ISSUE: IssuesUpdateIssue,
        PathValues.ISSUES_ADD_ISSUE: IssuesAddIssue,
        PathValues.ISSUES_DELETE_ISSUE: IssuesDeleteIssue,
        PathValues.JOBS_GET_JOBS: JobsGetJobs,
        PathValues.JOBS_GET_TRAINING_JOBS: JobsGetTrainingJobs,
        PathValues.JOBS_IS_TRAINING_JOB_RUNNING: JobsIsTrainingJobRunning,
        PathValues.JOBS_GET_ORGANIZATION_JOBS: JobsGetOrganizationJobs,
        PathValues.JOBS_STOP_JOB: JobsStopJob,
        PathValues.JOBS_TERMINATE_JOB: JobsTerminateJob,
        PathValues.JOBS_WARMUP: JobsWarmup,
        PathValues.JOBS_ADD_EXPORT_MODEL_JOB: JobsAddExportModelJob,
        PathValues.JOBS_TRAIN_FROM_SCRATCH: JobsTrainFromScratch,
        PathValues.JOBS_CONTINUE_TRAIN: JobsContinueTrain,
        PathValues.JOBS_TRAIN_FROM_INITIAL_WEIGHTS: JobsTrainFromInitialWeights,
        PathValues.JOBS_EVALUATE: JobsEvaluate,
        PathValues.JOBS_SAMPLE_ANALYSIS: JobsSampleAnalysis,
        PathValues.JOBS_POPULATION_EXPLORATION: JobsPopulationExploration,
        PathValues.JOBS_SAMPLE_SELECTION: JobsSampleSelection,
        PathValues.JOBS_GET_MACHINE_TYPES: JobsGetMachineTypes,
        PathValues.JOBS_SET_MACHINE_TYPE: JobsSetMachineType,
        PathValues.METADATA_GET_MAX_ACTIVE_USERS: MetadataGetMaxActiveUsers,
        PathValues.METADATA_GET_STATISTICS: MetadataGetStatistics,
        PathValues.MODELTESTS_CREATE_MODEL_TEST: ModelTestsCreateModelTest,
        PathValues.MODELTESTS_UPDATE_MODEL_TEST: ModelTestsUpdateModelTest,
        PathValues.MODELTESTS_GET_SINGLE_MODEL_TEST: ModelTestsGetSingleModelTest,
        PathValues.MODELTESTS_GET_ALL_PROJECT_MODEL_TESTS: ModelTestsGetAllProjectModelTests,
        PathValues.MODELTESTS_DELETE_MODEL_TEST: ModelTestsDeleteModelTest,
        PathValues.MODELTESTS_GET_MODEL_TEST_RESULT: ModelTestsGetModelTestResult,
        PathValues.MODELMETRICS_GET_MODEL_EPOCH_LOSS: ModelmetricsGetModelEpochLoss,
        PathValues.MODELMETRICS_GET_XYCHART: ModelmetricsGetXYChart,
        PathValues.MODELMETRICS_GET_HEATMAP_CHART: ModelmetricsGetHeatmapChart,
        PathValues.MODELMETRICS_GET_TABLE_CHART: ModelmetricsGetTableChart,
        PathValues.MODELMETRICS_GET_CONFUSION_METRIC_NAMES: ModelmetricsGetConfusionMetricNames,
        PathValues.MODELMETRICS_GET_BALANCED_ACCURACY: ModelmetricsGetBalancedAccuracy,
        PathValues.MODELMETRICS_GET_F1SCORE: ModelmetricsGetF1Score,
        PathValues.MODELMETRICS_GET_PR_CURVE: ModelmetricsGetPrCurve,
        PathValues.MODELMETRICS_GET_ROC: ModelmetricsGetRoc,
        PathValues.MODELS_GET_MODELS_BY_HASH: ModelsGetModelsByHash,
        PathValues.MODELS_GET_MODELS_BY_VERSION_ID: ModelsGetModelsByVersionId,
        PathValues.MODELS_GET_RECENT_ORGANIZATION_MODELS: ModelsGetRecentOrganizationModels,
        PathValues.MODELS_DELETE_MODEL: ModelsDeleteModel,
        PathValues.MONITOR_HEALTH_CHECK: MonitorHealthCheck,
        PathValues.NOTIFICATIONS_GET_NOTIFICATIONS: NotificationsGetNotifications,
        PathValues.NOTIFICATIONS_SET_USER_NOTIFICATIONS_AS_READ: NotificationsSetUserNotificationsAsRead,
        PathValues.ORGANIZATIONS_GET_ORGANIZATIONS: OrganizationsGetOrganizations,
        PathValues.ORGANIZATIONS_UPDATE_ORGANIZATION_PUBLIC_NAME: OrganizationsUpdateOrganizationPublicName,
        PathValues.ORGANIZATIONS_CREATE_ORGANIZATION: OrganizationsCreateOrganization,
        PathValues.ORGANIZATIONS_DELETE_ORGANIZATION: OrganizationsDeleteOrganization,
        PathValues.ORGANIZATIONS_SET_DEFAULT_ORGANIZATION: OrganizationsSetDefaultOrganization,
        PathValues.PROJECTS_ADD_PROJECT: ProjectsAddProject,
        PathValues.PROJECTS_GET_PROJECTS: ProjectsGetProjects,
        PathValues.PROJECTS_LOAD_MODEL: ProjectsLoadModel,
        PathValues.PROJECTS_DELETE_PROJECT: ProjectsDeleteProject,
        PathValues.PROJECTS_TRASH_PROJECT: ProjectsTrashProject,
        PathValues.PROJECTS_GET_CURRENT_PROJECT_VERSION: ProjectsGetCurrentProjectVersion,
        PathValues.SECRETMANAGER_ADD_SECRET_MANAGER: SecretManagerAddSecretManager,
        PathValues.SECRETMANAGER_TRASH_SECRET_MANAGER: SecretManagerTrashSecretManager,
        PathValues.SECRETMANAGER_GET_SECRET_MANAGER_LIST: SecretManagerGetSecretManagerList,
        PathValues.SECRETMANAGER_UPDATE_SECRET_MANAGER: SecretManagerUpdateSecretManager,
        PathValues.USERS_GET_ORGANIZATION_SLIM_USER_DATA: UsersGetOrganizationSlimUserData,
        PathValues.USERS_GET_ALL_SLIM_USER_DATA: UsersGetAllSlimUserData,
        PathValues.USERS_UPDATE_USER_STATUS: UsersUpdateUserStatus,
        PathValues.USERS_UPDATE_USER_ORGANIZATION: UsersUpdateUserOrganization,
        PathValues.USERS_UPDATE_USER_ROLE: UsersUpdateUserRole,
        PathValues.USERS_UPDATE_USER_NAME: UsersUpdateUserName,
        PathValues.USERS_DELETE_USER_BY_ID: UsersDeleteUserById,
        PathValues.VERSIONS_IMPORT_MODEL: VersionsImportModel,
        PathValues.VERSIONS_ADD_VERSION: VersionsAddVersion,
        PathValues.VERSIONS_LOAD_VERSION: VersionsLoadVersion,
        PathValues.VERSIONS_DELETE_VERSION: VersionsDeleteVersion,
        PathValues.VERSIONS_UPDATE_VERSION: VersionsUpdateVersion,
        PathValues.VERSIONS_GET_PROJECT_SLIM_VERSIONS: VersionsGetProjectSlimVersions,
        PathValues.VERSIONS_GET_UPLOAD_SIGNED_URL: VersionsGetUploadSignedUrl,
        PathValues.VISUALIZATIONS_GET_VISUALIZATION: VisualizationsGetVisualization,
        PathValues.VISUALIZATIONS_GET_MODEL_VISUALIZATIONS: VisualizationsGetModelVisualizations,
        PathValues.VISUALIZATIONS_SAVE_ANALYZER_LAYOUT: VisualizationsSaveAnalyzerLayout,
        PathValues.VISUALIZATIONS_DELETE_VISUALIZATIONS: VisualizationsDeleteVisualizations,
        PathValues.VISUALIZATIONS_GET_STORED_RESOURCE_URL: VisualizationsGetStoredResourceUrl,
    }
)



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class Dataset(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "createdAt",
            "access",
            "organization",
            "name",
            "_id",
        }
        
        class properties:
            _id = schemas.StrSchema
            
            
            class name(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'name':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            organization = schemas.StrSchema
        
            @staticmethod
            def access() -> typing.Type['DatasetAccess']:
                return DatasetAccess
            createdAt = schemas.StrSchema
            sourceDatasetId = schemas.StrSchema
        
            @staticmethod
            def latestValidVersion() -> typing.Type['DatasetVersion']:
                return DatasetVersion
        
            @staticmethod
            def latestVersion() -> typing.Type['DatasetVersion']:
                return DatasetVersion
            __annotations__ = {
                "_id": _id,
                "name": name,
                "organization": organization,
                "access": access,
                "createdAt": createdAt,
                "sourceDatasetId": sourceDatasetId,
                "latestValidVersion": latestValidVersion,
                "latestVersion": latestVersion,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    createdAt: MetaOapg.properties.createdAt
    access: 'DatasetAccess'
    organization: MetaOapg.properties.organization
    name: MetaOapg.properties.name
    _id: MetaOapg.properties._id
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createdAt"]) -> MetaOapg.properties.createdAt: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["access"]) -> 'DatasetAccess': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["organization"]) -> MetaOapg.properties.organization: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["_id"]) -> MetaOapg.properties._id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["sourceDatasetId"]) -> MetaOapg.properties.sourceDatasetId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["latestValidVersion"]) -> 'DatasetVersion': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["latestVersion"]) -> 'DatasetVersion': ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["createdAt"], typing_extensions.Literal["access"], typing_extensions.Literal["organization"], typing_extensions.Literal["name"], typing_extensions.Literal["_id"], typing_extensions.Literal["sourceDatasetId"], typing_extensions.Literal["latestValidVersion"], typing_extensions.Literal["latestVersion"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createdAt"]) -> MetaOapg.properties.createdAt: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["access"]) -> 'DatasetAccess': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["organization"]) -> MetaOapg.properties.organization: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["_id"]) -> MetaOapg.properties._id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["sourceDatasetId"]) -> typing.Union[MetaOapg.properties.sourceDatasetId, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["latestValidVersion"]) -> typing.Union['DatasetVersion', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["latestVersion"]) -> typing.Union['DatasetVersion', schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["createdAt"], typing_extensions.Literal["access"], typing_extensions.Literal["organization"], typing_extensions.Literal["name"], typing_extensions.Literal["_id"], typing_extensions.Literal["sourceDatasetId"], typing_extensions.Literal["latestValidVersion"], typing_extensions.Literal["latestVersion"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        createdAt: typing.Union[MetaOapg.properties.createdAt, str, ],
        access: 'DatasetAccess',
        organization: typing.Union[MetaOapg.properties.organization, str, ],
        name: typing.Union[MetaOapg.properties.name, None, str, ],
        _id: typing.Union[MetaOapg.properties._id, str, ],
        sourceDatasetId: typing.Union[MetaOapg.properties.sourceDatasetId, str, schemas.Unset] = schemas.unset,
        latestValidVersion: typing.Union['DatasetVersion', schemas.Unset] = schemas.unset,
        latestVersion: typing.Union['DatasetVersion', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'Dataset':
        return super().__new__(
            cls,
            *args,
            createdAt=createdAt,
            access=access,
            organization=organization,
            name=name,
            _id=_id,
            sourceDatasetId=sourceDatasetId,
            latestValidVersion=latestValidVersion,
            latestVersion=latestVersion,
            _configuration=_configuration,
        )

from openapi_client.model.dataset_access import DatasetAccess
from openapi_client.model.dataset_version import DatasetVersion



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class GetMachineTypesResponse(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "defaultCpuType",
            "defaultGpuType",
            "options",
        }
        
        class properties:
            
            
            class options(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['MachineTypeOption']:
                        return MachineTypeOption
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['MachineTypeOption'], typing.List['MachineTypeOption']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'options':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'MachineTypeOption':
                    return super().__getitem__(i)
            defaultCpuType = schemas.StrSchema
            defaultGpuType = schemas.StrSchema
            __annotations__ = {
                "options": options,
                "defaultCpuType": defaultCpuType,
                "defaultGpuType": defaultGpuType,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    defaultCpuType: MetaOapg.properties.defaultCpuType
    defaultGpuType: MetaOapg.properties.defaultGpuType
    options: MetaOapg.properties.options
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["defaultCpuType"]) -> MetaOapg.properties.defaultCpuType: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["defaultGpuType"]) -> MetaOapg.properties.defaultGpuType: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["options"]) -> MetaOapg.properties.options: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["defaultCpuType"], typing_extensions.Literal["defaultGpuType"], typing_extensions.Literal["options"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["defaultCpuType"]) -> MetaOapg.properties.defaultCpuType: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["defaultGpuType"]) -> MetaOapg.properties.defaultGpuType: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["options"]) -> MetaOapg.properties.options: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["defaultCpuType"], typing_extensions.Literal["defaultGpuType"], typing_extensions.Literal["options"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        defaultCpuType: typing.Union[MetaOapg.properties.defaultCpuType, str, ],
        defaultGpuType: typing.Union[MetaOapg.properties.defaultGpuType, str, ],
        options: typing.Union[MetaOapg.properties.options, list, tuple, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'GetMachineTypesResponse':
        return super().__new__(
            cls,
            *args,
            defaultCpuType=defaultCpuType,
            defaultGpuType=defaultGpuType,
            options=options,
            _configuration=_configuration,
        )

from openapi_client.model.machine_type_option import MachineTypeOption



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class XYChart(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    XyChart represents a single chart element of either type Line, Area or Bar.
The charts have a parameter ModelId so that they can represent this visually and so they can be grouped by this param for horizontal grouping
Charts with the same modelId will appear in the same row next to each other, charts with different modelIds will appear in different rows
The meta element contains information such as the charts type and info on the axis such as their range, their display names, types, labels and more
The charts contains the chart data including the model the chart is related to, the lines, bars or areas and the dataseries points related to them
    """


    class MetaOapg:
        required = {
            "data",
            "meta",
        }
        
        class properties:
            
            
            class data(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['Line']:
                        return Line
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['Line'], typing.List['Line']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'data':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'Line':
                    return super().__getitem__(i)
        
            @staticmethod
            def meta() -> typing.Type['XYChartsMeta']:
                return XYChartsMeta
            __annotations__ = {
                "data": data,
                "meta": meta,
            }
    
    data: MetaOapg.properties.data
    meta: 'XYChartsMeta'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["data"]) -> MetaOapg.properties.data: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["meta"]) -> 'XYChartsMeta': ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["data", "meta", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["data"]) -> MetaOapg.properties.data: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["meta"]) -> 'XYChartsMeta': ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["data", "meta", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        data: typing.Union[MetaOapg.properties.data, list, tuple, ],
        meta: 'XYChartsMeta',
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'XYChart':
        return super().__new__(
            cls,
            *args,
            data=data,
            meta=meta,
            _configuration=_configuration,
            **kwargs,
        )

from openapi_client.model.line import Line
from openapi_client.model.xy_charts_meta import XYChartsMeta



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class UserData(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "role",
            "organizationName",
            "recordSession",
            "_id",
            "local",
            "activated",
        }
        
        class properties:
            _id = schemas.StrSchema
            recordSession = schemas.BoolSchema
        
            @staticmethod
            def role() -> typing.Type['UserRole']:
                return UserRole
        
            @staticmethod
            def local() -> typing.Type['UserDataLocal']:
                return UserDataLocal
            organizationName = schemas.StrSchema
            activated = schemas.BoolSchema
        
            @staticmethod
            def metadata() -> typing.Type['UserDataMetadata']:
                return UserDataMetadata
            kibanaSpaceId = schemas.StrSchema
        
            @staticmethod
            def singleUserMode() -> typing.Type['SingleUserModeSettings']:
                return SingleUserModeSettings
            __annotations__ = {
                "_id": _id,
                "recordSession": recordSession,
                "role": role,
                "local": local,
                "organizationName": organizationName,
                "activated": activated,
                "metadata": metadata,
                "kibanaSpaceId": kibanaSpaceId,
                "singleUserMode": singleUserMode,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    role: 'UserRole'
    organizationName: MetaOapg.properties.organizationName
    recordSession: MetaOapg.properties.recordSession
    _id: MetaOapg.properties._id
    local: 'UserDataLocal'
    activated: MetaOapg.properties.activated
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["role"]) -> 'UserRole': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["organizationName"]) -> MetaOapg.properties.organizationName: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["recordSession"]) -> MetaOapg.properties.recordSession: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["_id"]) -> MetaOapg.properties._id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["local"]) -> 'UserDataLocal': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["activated"]) -> MetaOapg.properties.activated: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["metadata"]) -> 'UserDataMetadata': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["kibanaSpaceId"]) -> MetaOapg.properties.kibanaSpaceId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["singleUserMode"]) -> 'SingleUserModeSettings': ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["role"], typing_extensions.Literal["organizationName"], typing_extensions.Literal["recordSession"], typing_extensions.Literal["_id"], typing_extensions.Literal["local"], typing_extensions.Literal["activated"], typing_extensions.Literal["metadata"], typing_extensions.Literal["kibanaSpaceId"], typing_extensions.Literal["singleUserMode"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["role"]) -> 'UserRole': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["organizationName"]) -> MetaOapg.properties.organizationName: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["recordSession"]) -> MetaOapg.properties.recordSession: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["_id"]) -> MetaOapg.properties._id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["local"]) -> 'UserDataLocal': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["activated"]) -> MetaOapg.properties.activated: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["metadata"]) -> typing.Union['UserDataMetadata', schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["kibanaSpaceId"]) -> typing.Union[MetaOapg.properties.kibanaSpaceId, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["singleUserMode"]) -> typing.Union['SingleUserModeSettings', schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["role"], typing_extensions.Literal["organizationName"], typing_extensions.Literal["recordSession"], typing_extensions.Literal["_id"], typing_extensions.Literal["local"], typing_extensions.Literal["activated"], typing_extensions.Literal["metadata"], typing_extensions.Literal["kibanaSpaceId"], typing_extensions.Literal["singleUserMode"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        role: 'UserRole',
        organizationName: typing.Union[MetaOapg.properties.organizationName, str, ],
        recordSession: typing.Union[MetaOapg.properties.recordSession, bool, ],
        _id: typing.Union[MetaOapg.properties._id, str, ],
        local: 'UserDataLocal',
        activated: typing.Union[MetaOapg.properties.activated, bool, ],
        metadata: typing.Union['UserDataMetadata', schemas.Unset] = schemas.unset,
        kibanaSpaceId: typing.Union[MetaOapg.properties.kibanaSpaceId, str, schemas.Unset] = schemas.unset,
        singleUserMode: typing.Union['SingleUserModeSettings', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'UserData':
        return super().__new__(
            cls,
            *args,
            role=role,
            organizationName=organizationName,
            recordSession=recordSession,
            _id=_id,
            local=local,
            activated=activated,
            metadata=metadata,
            kibanaSpaceId=kibanaSpaceId,
            singleUserMode=singleUserMode,
            _configuration=_configuration,
        )

from openapi_client.model.single_user_mode_settings import SingleUserModeSettings
from openapi_client.model.user_data_local import UserDataLocal
from openapi_client.model.user_data_metadata import UserDataMetadata
from openapi_client.model.user_role import UserRole



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class StopJobResponse(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "job_id",
            "status",
        }
        
        class properties:
            
            
            class status(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "sent_stop_signal": "SENT_STOP_SIGNAL",
                    }
                
                @schemas.classproperty
                def SENT_STOP_SIGNAL(cls):
                    return cls("sent_stop_signal")
            job_id = schemas.StrSchema
            __annotations__ = {
                "status": status,
                "job_id": job_id,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    job_id: MetaOapg.properties.job_id
    status: MetaOapg.properties.status
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["job_id"]) -> MetaOapg.properties.job_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["job_id"], typing_extensions.Literal["status"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["job_id"]) -> MetaOapg.properties.job_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["job_id"], typing_extensions.Literal["status"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        job_id: typing.Union[MetaOapg.properties.job_id, str, ],
        status: typing.Union[MetaOapg.properties.status, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'StopJobResponse':
        return super().__new__(
            cls,
            *args,
            job_id=job_id,
            status=status,
            _configuration=_configuration,
        )



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class XMetaAxis(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    DisplayName is the name shown on the Y column
EsName is the internal name as presented in Elastic. (i.e.: if the key in elastic is metrics.state.keyword,
this would be the value we store in EsName and use when creating filters based on this axis but we would show it as 'state' which we return in the displayname)
Domain sets the axis range (domain equal to min:0 and max:100 will have a range of values between 0 and 100). The default domain causes 'datamin' and 'datamax' causes the webui to calculate the domain.
   TODO: look into if the domain can be removed from the interface and calculated by recharts only.
AxisType states the format of the point values. If the distribution type is continuous this is number, else catagory.
   TODO: look into issues this causes with values being numeric and the type being catagory causing the chart to split horizontaly by line.
    """


    class MetaOapg:
        required = {
            "displayName",
            "domain",
            "esName",
            "axisType",
        }
        
        class properties:
        
            @staticmethod
            def axisType() -> typing.Type['AxisType']:
                return AxisType
        
            @staticmethod
            def domain() -> typing.Type['Domain']:
                return Domain
            esName = schemas.StrSchema
            displayName = schemas.StrSchema
            __annotations__ = {
                "axisType": axisType,
                "domain": domain,
                "esName": esName,
                "displayName": displayName,
            }
    
    displayName: MetaOapg.properties.displayName
    domain: 'Domain'
    esName: MetaOapg.properties.esName
    axisType: 'AxisType'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["axisType"]) -> 'AxisType': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["domain"]) -> 'Domain': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["esName"]) -> MetaOapg.properties.esName: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["displayName"]) -> MetaOapg.properties.displayName: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["axisType", "domain", "esName", "displayName", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["axisType"]) -> 'AxisType': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["domain"]) -> 'Domain': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["esName"]) -> MetaOapg.properties.esName: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["displayName"]) -> MetaOapg.properties.displayName: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["axisType", "domain", "esName", "displayName", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        displayName: typing.Union[MetaOapg.properties.displayName, str, ],
        domain: 'Domain',
        esName: typing.Union[MetaOapg.properties.esName, str, ],
        axisType: 'AxisType',
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'XMetaAxis':
        return super().__new__(
            cls,
            *args,
            displayName=displayName,
            domain=domain,
            esName=esName,
            axisType=axisType,
            _configuration=_configuration,
            **kwargs,
        )

from openapi_client.model.axis_type import AxisType
from openapi_client.model.domain import Domain



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class Point(
    schemas.ListSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    In order to minimize the size of the response and not return repeating param names for tens of thousands of values,
the Point key names (xField key, yField key and metadata keys) are stored in the metadata section since they are the same for all charts in the response.
The first element in the tuple (the NumberOrString) is the xField value
The second element in the tuiple (the number) is the yField value
the third element in the tuple (the NumerOrString[]) is an array of numbers or string which are the values for the different metadata elements as shown in the metadata section of the response
The order of the metadata field names array correlates to the order of this metadata array.
    """


    class MetaOapg:
        
        @staticmethod
        def items() -> typing.Type['PointValueTypes']:
            return PointValueTypes

    def __new__(
        cls,
        arg: typing.Union[typing.Tuple['PointValueTypes'], typing.List['PointValueTypes']],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'Point':
        return super().__new__(
            cls,
            arg,
            _configuration=_configuration,
        )

    def __getitem__(self, i: int) -> 'PointValueTypes':
        return super().__getitem__(i)

from openapi_client.model.point_value_types import PointValueTypes



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401
GetF1ScoreParams = schemas.Schema



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class Notification(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "createdAt",
            "identifier",
            "organization",
            "isRead",
            "_id",
            "title",
            "user",
            "messageData",
        }
        
        class properties:
            _id = schemas.StrSchema
            organization = schemas.StrSchema
            user = schemas.StrSchema
            title = schemas.StrSchema
        
            @staticmethod
            def messageData() -> typing.Type['CustomMessageData']:
                return CustomMessageData
            identifier = schemas.StrSchema
            createdAt = schemas.DateTimeSchema
            isRead = schemas.BoolSchema
        
            @staticmethod
            def context() -> typing.Type['JobNotificationContext']:
                return JobNotificationContext
            __annotations__ = {
                "_id": _id,
                "organization": organization,
                "user": user,
                "title": title,
                "messageData": messageData,
                "identifier": identifier,
                "createdAt": createdAt,
                "isRead": isRead,
                "context": context,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    createdAt: MetaOapg.properties.createdAt
    identifier: MetaOapg.properties.identifier
    organization: MetaOapg.properties.organization
    isRead: MetaOapg.properties.isRead
    _id: MetaOapg.properties._id
    title: MetaOapg.properties.title
    user: MetaOapg.properties.user
    messageData: 'CustomMessageData'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createdAt"]) -> MetaOapg.properties.createdAt: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["identifier"]) -> MetaOapg.properties.identifier: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["organization"]) -> MetaOapg.properties.organization: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["isRead"]) -> MetaOapg.properties.isRead: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["_id"]) -> MetaOapg.properties._id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["title"]) -> MetaOapg.properties.title: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["user"]) -> MetaOapg.properties.user: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["messageData"]) -> 'CustomMessageData': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["context"]) -> 'JobNotificationContext': ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["createdAt"], typing_extensions.Literal["identifier"], typing_extensions.Literal["organization"], typing_extensions.Literal["isRead"], typing_extensions.Literal["_id"], typing_extensions.Literal["title"], typing_extensions.Literal["user"], typing_extensions.Literal["messageData"], typing_extensions.Literal["context"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createdAt"]) -> MetaOapg.properties.createdAt: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["identifier"]) -> MetaOapg.properties.identifier: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["organization"]) -> MetaOapg.properties.organization: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["isRead"]) -> MetaOapg.properties.isRead: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["_id"]) -> MetaOapg.properties._id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["title"]) -> MetaOapg.properties.title: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["user"]) -> MetaOapg.properties.user: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["messageData"]) -> 'CustomMessageData': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["context"]) -> typing.Union['JobNotificationContext', schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["createdAt"], typing_extensions.Literal["identifier"], typing_extensions.Literal["organization"], typing_extensions.Literal["isRead"], typing_extensions.Literal["_id"], typing_extensions.Literal["title"], typing_extensions.Literal["user"], typing_extensions.Literal["messageData"], typing_extensions.Literal["context"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        createdAt: typing.Union[MetaOapg.properties.createdAt, str, datetime, ],
        identifier: typing.Union[MetaOapg.properties.identifier, str, ],
        organization: typing.Union[MetaOapg.properties.organization, str, ],
        isRead: typing.Union[MetaOapg.properties.isRead, bool, ],
        _id: typing.Union[MetaOapg.properties._id, str, ],
        title: typing.Union[MetaOapg.properties.title, str, ],
        user: typing.Union[MetaOapg.properties.user, str, ],
        messageData: 'CustomMessageData',
        context: typing.Union['JobNotificationContext', schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'Notification':
        return super().__new__(
            cls,
            *args,
            createdAt=createdAt,
            identifier=identifier,
            organization=organization,
            isRead=isRead,
            _id=_id,
            title=title,
            user=user,
            messageData=messageData,
            context=context,
            _configuration=_configuration,
        )

from openapi_client.model.custom_message_data import CustomMessageData
from openapi_client.model.job_notification_context import JobNotificationContext



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class LeapDataType(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        enum_value_to_name = {
            "Image": "IMAGE",
            "Text": "TEXT",
            "Graph": "GRAPH",
            "HorizontalBar": "HORIZONTAL_BAR",
            "ImageMask": "IMAGE_MASK",
            "TextMask": "TEXT_MASK",
            "ImageWithBBox": "IMAGE_WITH_BBOX",
        }
    
    @schemas.classproperty
    def IMAGE(cls):
        return cls("Image")
    
    @schemas.classproperty
    def TEXT(cls):
        return cls("Text")
    
    @schemas.classproperty
    def GRAPH(cls):
        return cls("Graph")
    
    @schemas.classproperty
    def HORIZONTAL_BAR(cls):
        return cls("HorizontalBar")
    
    @schemas.classproperty
    def IMAGE_MASK(cls):
        return cls("ImageMask")
    
    @schemas.classproperty
    def TEXT_MASK(cls):
        return cls("TextMask")
    
    @schemas.classproperty
    def IMAGE_WITH_BBOX(cls):
        return cls("ImageWithBBox")



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class ESFilter(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "field",
            "value",
            "operator",
        }
        
        class properties:
        
            @staticmethod
            def operator() -> typing.Type['FilterOperatorType']:
                return FilterOperatorType
            field = schemas.StrSchema
        
            @staticmethod
            def value() -> typing.Type['ESFilterValue']:
                return ESFilterValue
            disable = schemas.BoolSchema
            __annotations__ = {
                "operator": operator,
                "field": field,
                "value": value,
                "disable": disable,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    field: MetaOapg.properties.field
    value: 'ESFilterValue'
    operator: 'FilterOperatorType'
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["field"]) -> MetaOapg.properties.field: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["value"]) -> 'ESFilterValue': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["operator"]) -> 'FilterOperatorType': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["disable"]) -> MetaOapg.properties.disable: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["field"], typing_extensions.Literal["value"], typing_extensions.Literal["operator"], typing_extensions.Literal["disable"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["field"]) -> MetaOapg.properties.field: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["value"]) -> 'ESFilterValue': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["operator"]) -> 'FilterOperatorType': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["disable"]) -> typing.Union[MetaOapg.properties.disable, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["field"], typing_extensions.Literal["value"], typing_extensions.Literal["operator"], typing_extensions.Literal["disable"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        field: typing.Union[MetaOapg.properties.field, str, ],
        value: 'ESFilterValue',
        operator: 'FilterOperatorType',
        disable: typing.Union[MetaOapg.properties.disable, bool, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'ESFilter':
        return super().__new__(
            cls,
            *args,
            field=field,
            value=value,
            operator=operator,
            disable=disable,
            _configuration=_configuration,
        )

from openapi_client.model.es_filter_value import ESFilterValue
from openapi_client.model.filter_operator_type import FilterOperatorType



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class HorizontalBarScatterLabel(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "horizontal_bar_visualizations",
            "type",
        }
        
        class properties:
            type = schemas.StrSchema
            
            
            class horizontal_bar_visualizations(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['HorizontalBarViz']:
                        return HorizontalBarViz
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['HorizontalBarViz'], typing.List['HorizontalBarViz']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'horizontal_bar_visualizations':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'HorizontalBarViz':
                    return super().__getitem__(i)
            input_name = schemas.StrSchema
            __annotations__ = {
                "type": type,
                "horizontal_bar_visualizations": horizontal_bar_visualizations,
                "input_name": input_name,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    horizontal_bar_visualizations: MetaOapg.properties.horizontal_bar_visualizations
    type: MetaOapg.properties.type
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["horizontal_bar_visualizations"]) -> MetaOapg.properties.horizontal_bar_visualizations: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["input_name"]) -> MetaOapg.properties.input_name: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["horizontal_bar_visualizations"], typing_extensions.Literal["type"], typing_extensions.Literal["input_name"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["horizontal_bar_visualizations"]) -> MetaOapg.properties.horizontal_bar_visualizations: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["input_name"]) -> typing.Union[MetaOapg.properties.input_name, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["horizontal_bar_visualizations"], typing_extensions.Literal["type"], typing_extensions.Literal["input_name"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        horizontal_bar_visualizations: typing.Union[MetaOapg.properties.horizontal_bar_visualizations, list, tuple, ],
        type: typing.Union[MetaOapg.properties.type, str, ],
        input_name: typing.Union[MetaOapg.properties.input_name, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'HorizontalBarScatterLabel':
        return super().__new__(
            cls,
            *args,
            horizontal_bar_visualizations=horizontal_bar_visualizations,
            type=type,
            input_name=input_name,
            _configuration=_configuration,
        )

from openapi_client.model.horizontal_bar_viz import HorizontalBarViz



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class BasicVisualizationInfo(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "job_type",
            "analyze_type",
            "guid",
        }
        
        class properties:
        
            @staticmethod
            def job_type() -> typing.Type['JobTypeEnum']:
                return JobTypeEnum
        
            @staticmethod
            def analyze_type() -> typing.Type['AnalyzeTypeEnum']:
                return AnalyzeTypeEnum
            guid = schemas.StrSchema
            __annotations__ = {
                "job_type": job_type,
                "analyze_type": analyze_type,
                "guid": guid,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    job_type: 'JobTypeEnum'
    analyze_type: 'AnalyzeTypeEnum'
    guid: MetaOapg.properties.guid
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["job_type"]) -> 'JobTypeEnum': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["analyze_type"]) -> 'AnalyzeTypeEnum': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["guid"]) -> MetaOapg.properties.guid: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["job_type"], typing_extensions.Literal["analyze_type"], typing_extensions.Literal["guid"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["job_type"]) -> 'JobTypeEnum': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["analyze_type"]) -> 'AnalyzeTypeEnum': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["guid"]) -> MetaOapg.properties.guid: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["job_type"], typing_extensions.Literal["analyze_type"], typing_extensions.Literal["guid"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        job_type: 'JobTypeEnum',
        analyze_type: 'AnalyzeTypeEnum',
        guid: typing.Union[MetaOapg.properties.guid, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'BasicVisualizationInfo':
        return super().__new__(
            cls,
            *args,
            job_type=job_type,
            analyze_type=analyze_type,
            guid=guid,
            _configuration=_configuration,
        )

from openapi_client.model.analyze_type_enum import AnalyzeTypeEnum
from openapi_client.model.job_type_enum import JobTypeEnum



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class SlimVersion(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "createdAt",
            "models",
            "notes",
            "createdBy",
            "branchName",
            "project",
            "_id",
            "isFavourite",
            "tags",
        }
        
        class properties:
            _id = schemas.StrSchema
            createdBy = schemas.StrSchema
            project = schemas.StrSchema
            branchName = schemas.StrSchema
            tags = schemas.StrSchema
            createdAt = schemas.DateTimeSchema
            notes = schemas.StrSchema
            isFavourite = schemas.BoolSchema
            
            
            class models(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['Model']:
                        return Model
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple['Model'], typing.List['Model']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'models':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'Model':
                    return super().__getitem__(i)
            
            
            class hash(
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin
            ):
            
            
                def __new__(
                    cls,
                    *args: typing.Union[None, str, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'hash':
                    return super().__new__(
                        cls,
                        *args,
                        _configuration=_configuration,
                    )
            __annotations__ = {
                "_id": _id,
                "createdBy": createdBy,
                "project": project,
                "branchName": branchName,
                "tags": tags,
                "createdAt": createdAt,
                "notes": notes,
                "isFavourite": isFavourite,
                "models": models,
                "hash": hash,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    createdAt: MetaOapg.properties.createdAt
    models: MetaOapg.properties.models
    notes: MetaOapg.properties.notes
    createdBy: MetaOapg.properties.createdBy
    branchName: MetaOapg.properties.branchName
    project: MetaOapg.properties.project
    _id: MetaOapg.properties._id
    isFavourite: MetaOapg.properties.isFavourite
    tags: MetaOapg.properties.tags
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createdAt"]) -> MetaOapg.properties.createdAt: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["models"]) -> MetaOapg.properties.models: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["notes"]) -> MetaOapg.properties.notes: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createdBy"]) -> MetaOapg.properties.createdBy: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["branchName"]) -> MetaOapg.properties.branchName: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["project"]) -> MetaOapg.properties.project: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["_id"]) -> MetaOapg.properties._id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["isFavourite"]) -> MetaOapg.properties.isFavourite: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["tags"]) -> MetaOapg.properties.tags: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["hash"]) -> MetaOapg.properties.hash: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["createdAt"], typing_extensions.Literal["models"], typing_extensions.Literal["notes"], typing_extensions.Literal["createdBy"], typing_extensions.Literal["branchName"], typing_extensions.Literal["project"], typing_extensions.Literal["_id"], typing_extensions.Literal["isFavourite"], typing_extensions.Literal["tags"], typing_extensions.Literal["hash"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createdAt"]) -> MetaOapg.properties.createdAt: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["models"]) -> MetaOapg.properties.models: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["notes"]) -> MetaOapg.properties.notes: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createdBy"]) -> MetaOapg.properties.createdBy: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["branchName"]) -> MetaOapg.properties.branchName: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["project"]) -> MetaOapg.properties.project: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["_id"]) -> MetaOapg.properties._id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["isFavourite"]) -> MetaOapg.properties.isFavourite: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["tags"]) -> MetaOapg.properties.tags: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["hash"]) -> typing.Union[MetaOapg.properties.hash, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["createdAt"], typing_extensions.Literal["models"], typing_extensions.Literal["notes"], typing_extensions.Literal["createdBy"], typing_extensions.Literal["branchName"], typing_extensions.Literal["project"], typing_extensions.Literal["_id"], typing_extensions.Literal["isFavourite"], typing_extensions.Literal["tags"], typing_extensions.Literal["hash"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        createdAt: typing.Union[MetaOapg.properties.createdAt, str, datetime, ],
        models: typing.Union[MetaOapg.properties.models, list, tuple, ],
        notes: typing.Union[MetaOapg.properties.notes, str, ],
        createdBy: typing.Union[MetaOapg.properties.createdBy, str, ],
        branchName: typing.Union[MetaOapg.properties.branchName, str, ],
        project: typing.Union[MetaOapg.properties.project, str, ],
        _id: typing.Union[MetaOapg.properties._id, str, ],
        isFavourite: typing.Union[MetaOapg.properties.isFavourite, bool, ],
        tags: typing.Union[MetaOapg.properties.tags, str, ],
        hash: typing.Union[MetaOapg.properties.hash, None, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'SlimVersion':
        return super().__new__(
            cls,
            *args,
            createdAt=createdAt,
            models=models,
            notes=notes,
            createdBy=createdBy,
            branchName=branchName,
            project=project,
            _id=_id,
            isFavourite=isFavourite,
            tags=tags,
            hash=hash,
            _configuration=_configuration,
        )

from openapi_client.model.model import Model



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class CustomVisualizationType(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        enum_value_to_name = {
            "Bar": "BAR",
            "Line": "LINE",
            "Area": "AREA",
            "Table": "TABLE",
            "Heatmap": "HEATMAP",
            "Donut": "DONUT",
            "Confusion Matrix": "CONFUSION_MATRIX",
        }
    
    @schemas.classproperty
    def BAR(cls):
        return cls("Bar")
    
    @schemas.classproperty
    def LINE(cls):
        return cls("Line")
    
    @schemas.classproperty
    def AREA(cls):
        return cls("Area")
    
    @schemas.classproperty
    def TABLE(cls):
        return cls("Table")
    
    @schemas.classproperty
    def HEATMAP(cls):
        return cls("Heatmap")
    
    @schemas.classproperty
    def DONUT(cls):
        return cls("Donut")
    
    @schemas.classproperty
    def CONFUSION_MATRIX(cls):
        return cls("Confusion Matrix")



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class ScatterInsightType(
    schemas.EnumBase,
    schemas.StrSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        enum_value_to_name = {
            "redundant_samples_cluster": "REDUNDANT_SAMPLES_CLUSTER",
            "weak_cluster": "WEAK_CLUSTER",
            "under_representation_cluster": "UNDER_REPRESENTATION_CLUSTER",
            "overfitting_cluster": "OVERFITTING_CLUSTER",
        }
    
    @schemas.classproperty
    def REDUNDANT_SAMPLES_CLUSTER(cls):
        return cls("redundant_samples_cluster")
    
    @schemas.classproperty
    def WEAK_CLUSTER(cls):
        return cls("weak_cluster")
    
    @schemas.classproperty
    def UNDER_REPRESENTATION_CLUSTER(cls):
        return cls("under_representation_cluster")
    
    @schemas.classproperty
    def OVERFITTING_CLUSTER(cls):
        return cls("overfitting_cluster")



# coding: utf-8

"""
    node-server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 0.0.237
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_client import schemas  # noqa: F401


class DatasetVersion(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "createdAt",
            "note",
            "metadata",
            "createdBy",
            "organization",
            "testStatus",
            "digest",
            "datasetId",
            "_id",
        }
        
        class properties:
            _id = schemas.StrSchema
            organization = schemas.StrSchema
            datasetId = schemas.StrSchema
            digest = schemas.StrSchema
            note = schemas.StrSchema
            createdAt = schemas.StrSchema
            createdBy = schemas.StrSchema
        
            @staticmethod
            def testStatus() -> typing.Type['TestStatus']:
                return TestStatus
        
            @staticmethod
            def metadata() -> typing.Type['DatasetMetadata']:
                return DatasetMetadata
            __annotations__ = {
                "_id": _id,
                "organization": organization,
                "datasetId": datasetId,
                "digest": digest,
                "note": note,
                "createdAt": createdAt,
                "createdBy": createdBy,
                "testStatus": testStatus,
                "metadata": metadata,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    createdAt: MetaOapg.properties.createdAt
    note: MetaOapg.properties.note
    metadata: 'DatasetMetadata'
    createdBy: MetaOapg.properties.createdBy
    organization: MetaOapg.properties.organization
    testStatus: 'TestStatus'
    digest: MetaOapg.properties.digest
    datasetId: MetaOapg.properties.datasetId
    _id: MetaOapg.properties._id
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createdAt"]) -> MetaOapg.properties.createdAt: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["note"]) -> MetaOapg.properties.note: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["metadata"]) -> 'DatasetMetadata': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["createdBy"]) -> MetaOapg.properties.createdBy: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["organization"]) -> MetaOapg.properties.organization: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["testStatus"]) -> 'TestStatus': ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["digest"]) -> MetaOapg.properties.digest: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["datasetId"]) -> MetaOapg.properties.datasetId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["_id"]) -> MetaOapg.properties._id: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["createdAt"], typing_extensions.Literal["note"], typing_extensions.Literal["metadata"], typing_extensions.Literal["createdBy"], typing_extensions.Literal["organization"], typing_extensions.Literal["testStatus"], typing_extensions.Literal["digest"], typing_extensions.Literal["datasetId"], typing_extensions.Literal["_id"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createdAt"]) -> MetaOapg.properties.createdAt: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["note"]) -> MetaOapg.properties.note: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["metadata"]) -> 'DatasetMetadata': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["createdBy"]) -> MetaOapg.properties.createdBy: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["organization"]) -> MetaOapg.properties.organization: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["testStatus"]) -> 'TestStatus': ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["digest"]) -> MetaOapg.properties.digest: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["datasetId"]) -> MetaOapg.properties.datasetId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["_id"]) -> MetaOapg.properties._id: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["createdAt"], typing_extensions.Literal["note"], typing_extensions.Literal["metadata"], typing_extensions.Literal["createdBy"], typing_extensions.Literal["organization"], typing_extensions.Literal["testStatus"], typing_extensions.Literal["digest"], typing_extensions.Literal["datasetId"], typing_extensions.Literal["_id"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        createdAt: typing.Union[MetaOapg.properties.createdAt, str, ],
        note: typing.Union[MetaOapg.properties.note, str, ],
        metadata: 'DatasetMetadata',
        createdBy: typing.Union[MetaOapg.properties.createdBy, str, ],
        organization: typing.Union[MetaOapg.properties.organization, str, ],
        testStatus: 'TestStatus',
        digest: typing.Union[MetaOapg.properties.digest, str, ],
        datasetId: typing.Union[MetaOapg.properties.datasetId, str, ],
        _id: typing.Union[MetaOapg.properties._id, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'DatasetVersion':
        return super().__new__(
            cls,
            *args,
            createdAt=createdAt,
            note=note,
            metadata=metadata,
            createdBy=createdBy,
            organization=organization,
            testStatus=testStatus,
            digest=digest,
            datasetId=datasetId,
            _id=_id,
            _configuration=_configuration,
        )

from openapi_client.model.dataset_metadata import DatasetMetadata
from openapi_client.model.test_status import TestStatus
